@@ -1,4 +1,4 @@
-highpass <- function(data, channel, cutoff = 50, data.name) {
+highpass <- function(data, channel, cutoff = 50, n = 5, data.name) {
     if (missing(data)) 
         stop("'data' argument is not specified")
     if (!is.emg(data)) 
@@ -13,9 +13,9 @@ highpass <- function(data, channel, cutoff = 50, data.name) {
     
     if (data$samplingrate == 0) 
         stop("The sampling rate is requiered")
-    bf <- butter(5, 2 * cutoff/data$samplingrate, type = "high")
+    bf <- butter(n, 2 * cutoff/data$samplingrate, type = "high")
     b <- signal::filter(bf, data$values)
     attributes(b) <- NULL
     object <- emg(b, data$samplingrate, data$units, data$data.name)
     return(object)
-} 
+}
